@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.59 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: client.c,v 1.60 2006/06/05 10:20:54 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -853,7 +853,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
     if (len >= (int) sizeof(un_sock_addr.sun_path)) {
       fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	      __FILE__, __PRETTY_FUNCTION__,
-	      len, sizeof(un_sock_addr.sun_path) - 1);
+	      len, (int) sizeof(un_sock_addr.sun_path) - 1);
       return;
     }
 
