@@ -18,7 +18,10 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
+#include <assert.h>
+
 #include "conf.h"
+#include "udp_header.h"
 
 nepim_global_t nepim_global = {
   "nepim",  /* prog_name */
@@ -77,8 +80,80 @@ nepim_global_t nepim_global = {
   -1,       /* nagle (client, boolean, -1 is don't change) */
   0,        /* udp_overhead (bytes) */
   0,        /* tcp_overhead (bytes) */
+  0,        /* sweep_random (boolean) */
+  1,        /* sweep_step (bytes) */
+  -1,       /* write_floor (bytes) */
+  -1,       /* write_ceil (bytes) */
+  -1,       /* server_write_floor (bytes) */
+  -1,       /* server_write_ceil (bytes) */
 
   0, /* oop source */
   0  /* source interface */
 };
 
+void nepim_conf_write_sweep_auto(int is_udp,
+				 int *write_floor,
+				 int *write_ceil)
+{
+  /*
+    -1: fixed: floor=max ceil=max
+    -2: auto:  floor=min ceil=max
+  */
+
+  if (is_udp) {
+      if (*write_floor == -1)
+	*write_floor = nepim_global.udp_write_size;
+
+      if (*write_floor < 0)
+	*write_floor = UDP_HEADER_LEN;
+
+      if (*write_ceil < 0)
+	*write_ceil = nepim_global.udp_write_size;
+
+    return;
+  }
+
+  if (*write_floor == -1)
+    *write_floor = nepim_global.tcp_write_size;
+
+  if (*write_floor < 0)
+    *write_floor = 0;
+
+  if (*write_ceil < 0)
+    *write_ceil = nepim_global.tcp_write_size;
+}
+
+void nepim_conf_write_sweep_fit(int is_udp,
+				int *write_floor,
+				int *write_ceil)
+{
+  if (is_udp) {
+      if (*write_floor < UDP_HEADER_LEN)
+	*write_floor = UDP_HEADER_LEN;
+
+      if (*write_ceil > nepim_global.udp_write_size)
+	*write_ceil = nepim_global.udp_write_size;
+
+      if (*write_floor > *write_ceil)
+	*write_floor = *write_ceil;
+
+      assert(*write_floor >= UDP_HEADER_LEN);
+      assert(*write_ceil <= nepim_global.udp_write_size);
+      assert(*write_floor <= *write_ceil);
+
+    return;
+  }
+
+  if (*write_floor < 0)
+    *write_floor = 0;
+
+  if (*write_ceil > nepim_global.tcp_write_size)
+    *write_ceil = nepim_global.tcp_write_size;
+
+  if (*write_floor > *write_ceil)
+    *write_floor = *write_ceil;
+
+  assert(*write_floor >= 0);
+  assert(*write_ceil <= nepim_global.tcp_write_size);
+  assert(*write_floor <= *write_ceil);
+}
