@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.71 2006/06/02 18:23:09 evertonm Exp $ */
+/* $Id: server.c,v 1.72 2006/06/05 10:20:54 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -888,7 +888,7 @@ static void *on_tcp_connect(oop_source *src, int sd,
   if (family == AF_UNIX)
     fprintf(stderr,
 	    "%d: UNIX incoming: path=%s (sockaddr_len=%d path_len=%d)\n",
-	    conn_sd, addr_buf, len, strlen(addr_buf));
+	    conn_sd, addr_buf, len, (int) strlen(addr_buf));
     else
       fprintf(stderr,
 	      "%d: TCP incoming: %s,%d\n",
@@ -1035,7 +1035,7 @@ static int spawn_unix_listener(const char *path)
   if (len >= (int) sizeof(un_sock_addr.sun_path)) {
     fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	    __FILE__, __PRETTY_FUNCTION__,
-	    len, sizeof(un_sock_addr.sun_path) - 1);
+	    len, (int) sizeof(un_sock_addr.sun_path) - 1);
     return 0;
   }
   
