@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.71 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.72 2006/06/05 10:20:54 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -1212,7 +1212,7 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
     if (len >= (int) sizeof(un_sock_addr.sun_path)) {
       fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	      __FILE__, __PRETTY_FUNCTION__,
-	      len, sizeof(un_sock_addr.sun_path) - 1);
+	      len, (int) sizeof(un_sock_addr.sun_path) - 1);
       return -1;
     }
 
