@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.96 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.97 2006/06/05 10:20:54 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -1149,7 +1149,7 @@ int nepim_unix_dgram_listener(const char *path)
   if (len >= (int) sizeof(un_sock_addr.sun_path)) {
     fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	    __FILE__, __PRETTY_FUNCTION__,
-	    len, sizeof(un_sock_addr.sun_path) - 1);
+	    len, (int) sizeof(un_sock_addr.sun_path) - 1);
     return 0;
   }
   
